---
title: <span class="badge object-type-scalar"></span> Kelvin
---
# <span class="badge object-type-scalar"></span> Kelvin

Temperature: Kelvin (K)

## Definition

```python
# Temperature: Kelvin (K)
Kelvin: typing.Literal["kelvin"] = "kelvin"
```
